"""
This script converts avi file by PIPP to an twitter-optimized MP4 files while maintaining the aspect ratio and resizing it to fit within a maximum resolution of 1920x1200 pixels.

Usage:
    python resize_video.py <video_path>
    or Drag and drop the AVI file into this scrypt.

Arguments:
    <video_path> : Path to the input video file.

Example:
    python resize_video.py input.avi
This will read 'input.avi', resize it to fit within 1920x1200 pixels while maintaining the aspect ratio, and save the output as 'input_adj.mp4'.
"""

import cv2
import numpy as np
import argparse

def main():
    parser = argparse.ArgumentParser(description="Convert movie file to mp4 file and resize maintaining aspect ratio")
    parser.add_argument("video_path", type=str, help="Path to the input video.")
    args = parser.parse_args()
    
    # Open the video
    cap = cv2.VideoCapture(args.video_path)
    
    # Get video properties
    fps = int(cap.get(cv2.CAP_PROP_FPS))
    width = int(cap.get(cv2.CAP_PROP_FRAME_WIDTH))
    height = int(cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
    print(width, height, fps)
    
    # Define the limits
    limit_smaller = 1200
    limit_greater = 1920
    
    # Determine the scaling factor based on the smaller dimension
    if width < height:
        scale = limit_smaller / width
        new_width = limit_smaller
        new_height = int(height * scale)
        
        if new_height > limit_greater:
            scale = limit_greater / height
            new_width = int(width * scale)
            new_height = limit_greater
    else:
        scale = limit_smaller / height
        new_height = limit_smaller
        new_width = int(width * scale)
        
        if new_width > limit_greater:
            scale = limit_greater / width
            new_height = int(height * scale)
            new_width = limit_greater

    print(f"New dimensions: {new_width}x{new_height}")
    
    # Define the codec and create a video writer object
    fourcc = cv2.VideoWriter_fourcc(*'H264')          # for twitter
    out = cv2.VideoWriter(args.video_path.replace('.avi', '_adj.mp4'), fourcc, fps, (new_width, new_height))

    # Set quality parameters (e.g., lower CRF for higher quality)
    out.set(cv2.VIDEOWRITER_PROP_QUALITY, 90)  # Set quality level (0-100, 100 is highest quality)

    # Read and process each frame
    count = 0
    while cap.isOpened():
        ret, frame = cap.read()
        if not ret:
            break
        # Resize the frame to the new dimensions
        resized_frame = cv2.resize(frame, (new_width, new_height))
        out.write(resized_frame)
        print(count)
        count += 1
    
    # Release resources
    cap.release()
    out.release()

# Uncomment the following line when testing the script outside this environment
if __name__ == "__main__":
    main()
